@@ -109,40 +109,3 @@ def get_tf_idf_weights(structures: list, section_name="Техническое з
             weight_tf_idf.append([dictionary[id], around(freq, decimals=3)])
         result.append(weight_tf_idf)
     return result
-
-
-def strings_similarity(s1: str, s2: str) -> float:
-    """
-    Возвращает коэффициент сходимости строк `s1` и `s2`.
-
-    :return: 0.0 — полностью раздичны, 1.0 — одинаковы.
-    """
-    s1_list = tokenize(s1)
-    s2_list = tokenize(s2)
-
-    if not s1_list or not s2_list:
-        return 0.0
-
-    l1 = []
-    l2 = []
-
-    s1_set = {w for w in s1_list}
-    s2_set = {w for w in s2_list}
-
-    # формируется словарь
-    rvector = s1_set.union(s2_set)
-    for w in rvector:
-        if w in s1_set:
-            l1.append(1)
-        else:
-            l1.append(0)
-        if w in s2_set:
-            l2.append(1)
-        else:
-            l2.append(0)
-
-    c = 0
-    for i in range(len(rvector)):
-        c += l1[i] * l2[i]
-    cosine = c / float((sum(l1) * sum(l2)) ** 0.5)
-    return cosine
