@@ -84,7 +84,7 @@ class Parser:
 
             if self.is_heading_of_sec(p_text_split[0]) and not self.is_table_element(paragraph, doc):
                 if p_text_split[0] != "" and p_text_split[1] != "":
-                    result[p_text_split[0]] = p_text_split[1]
+                    result[p_text_split[0]] = paragraph.text
         return result
 
     def get_sections_second(self, doc: Document) -> dict:
@@ -128,7 +128,7 @@ class Parser:
                     text_parent = self.sections_tree.get_leaf_sections()[i]
 
             if text_parent is not None:
-                text_parent.text = text
+                text_parent.text = text.strip()
 
     def iter_paragraphs(self, parent):
         if isinstance(parent, DocumentWithTable):
